﻿using Infragistics.Win;
using Infragistics.Win.UltraWinGrid;
using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Linq;
using System.Text;
using System.Threading.Tasks;
using System.Windows.Forms;

namespace CASE_186771
{
    public partial class Form1 : Form
    {
        public Form1()
        {
            InitializeComponent();

            ultraGrid1.DataSource = getTable();

            this.ultraGrid1.DisplayLayout.Override.AllowRowSummaries = AllowRowSummaries.True;

            ultraGrid1.DisplayLayout.Bands[0].Columns[2].Width = 200;

            ultraGrid1.DisplayLayout.Bands[0].Summaries.Add(SummaryType.Sum, ultraGrid1.DisplayLayout.Bands[0].Columns["col3"]);

            ultraGrid1.CreationFilter = new CustomButtonCreationFilter();
        }

        private DataTable getTable()
        {
            DataTable table = new DataTable();

            table.Columns.Add("col1", typeof(Int32));
            table.Columns.Add("col2", typeof(string));
            table.Columns.Add("col3", typeof(int));

            for (int i = 0; i < 5; i++)
            {
                table.Rows.Add(new object[] { i, "test" + i, i * 100 });
            }

            table.PrimaryKey = new DataColumn[] { table.Columns["col1"] };

            return table;
        }

        private void ultraGrid1_MouseEnterElement(object sender, UIElementEventArgs e)
        {
            UIElement element = e.Element;

            if (null == element)
                return;

            if ((element is ButtonUIElement) && (element.Parent is SummaryValueUIElement))
            {
                (element as ButtonUIElement).Appearance.ImageBackground = Image.FromFile(@"..\..\Images\Tulips.jpg");
            }
        }

        private void ultraGrid1_MouseLeaveElement(object sender, UIElementEventArgs e)
        {
            UIElement element = e.Element;

            if (null == element)
                return;

            if ((element is ButtonUIElement) && (element.Parent is SummaryValueUIElement))
            {
                (element as ButtonUIElement).Appearance.ImageBackground = Image.FromFile(@"..\..\Images\Penguins.jpg");
            }
        }
    }

    public class CustomButtonCreationFilter : IUIElementCreationFilter
    {
        public void AfterCreateChildElements(UIElement parent)
        {
            var parentHeaderElement = parent as SummaryValueUIElement;

            if (null != parentHeaderElement)
            {
                if (parentHeaderElement.SummaryValue.SummarySettings.SourceColumn.Key == "col3")
                {
                    var textElement = parent.ChildElements[0];

                    var buttonSize = new Size(100, textElement.Rect.Height + 2);
                    var buttonLocation = new Point(textElement.Rect.X + textElement.Rect.Width - 100, textElement.Rect.Y - 1);

                    var button = new ButtonUIElement(parent);
                    button.Rect = new Rectangle(buttonLocation, buttonSize);
                    button.Appearance = new Infragistics.Win.Appearance();
                    //button.Appearance.Image = summaryButton.Image;
                    button.Appearance.ImageBackground = Image.FromFile(@"..\..\Images\Penguins.jpg");
                    button.Appearance.ThemedElementAlpha = Alpha.Transparent;

                    button.Text = "Custom Button";
                    button.ElementClick += new UIElementEventHandler(searchButton_ElementClick);

                    parentHeaderElement.ChildElements.Add(button);
                }
            }
        }

        private void searchButton_ElementClick(object sender, UIElementEventArgs e)
        {
            MessageBox.Show("custom button is clicked!");
        }

        public bool BeforeCreateChildElements(UIElement parent)
        {
            return false;
        }
    }
}
